@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: webdings.pm,v 1.5 2004/06/15 09:14:54 fredo Exp $
+#   $Id: webdings.pm,v 1.8 2005/09/12 16:56:22 fredo Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::webdings;
 
-$fonts->{webdings}= {
+$FONTDATA = {
     'fontname' => 'Webdings',
     'type' => 'TrueType',
     'apiname' => 'Web',
@@ -530,7 +531,265 @@ $fonts->{webdings}= {
         'globe2' => '1000',                      # C+0xFD # U+0xF0FD
         'globe3' => '1000',                      # C+0xFE # U+0xF0FE
         'peace' => '1000',                       # C+0xFF # U+0xF0FF
-    }, # HORIZ. WIDTH TABLE
+    }, # UNICODE COMPAT TABLE
+    'uni' => [
+        0xF000,
+        0xF001,
+        0xF002,
+        0xF003,
+        0xF004,
+        0xF005,
+        0xF006,
+        0xF007,
+        0xF008,
+        0xF009,
+        0xF00A,
+        0xF00B,
+        0xF00C,
+        0xF00D,
+        0xF00E,
+        0xF00F,
+        0xF010,
+        0xF011,
+        0xF012,
+        0xF013,
+        0xF014,
+        0xF015,
+        0xF016,
+        0xF017,
+        0xF018,
+        0xF019,
+        0xF01A,
+        0xF01B,
+        0xF01C,
+        0xF01D,
+        0xF01E,
+        0xF01F,
+        0xF020,
+        0xF021,
+        0xF022,
+        0xF023,
+        0xF024,
+        0xF025,
+        0xF026,
+        0xF027,
+        0xF028,
+        0xF029,
+        0xF02A,
+        0xF02B,
+        0xF02C,
+        0xF02D,
+        0xF02E,
+        0xF02F,
+        0xF030,
+        0xF031,
+        0xF032,
+        0xF033,
+        0xF034,
+        0xF035,
+        0xF036,
+        0xF037,
+        0xF038,
+        0xF039,
+        0xF03A,
+        0xF03B,
+        0xF03C,
+        0xF03D,
+        0xF03E,
+        0xF03F,
+        0xF040,
+        0xF041,
+        0xF042,
+        0xF043,
+        0xF044,
+        0xF045,
+        0xF046,
+        0xF047,
+        0xF048,
+        0xF049,
+        0xF04A,
+        0xF04B,
+        0xF04C,
+        0xF04D,
+        0xF04E,
+        0xF04F,
+        0xF050,
+        0xF051,
+        0xF052,
+        0xF053,
+        0xF054,
+        0xF055,
+        0xF056,
+        0xF057,
+        0xF058,
+        0xF059,
+        0xF05A,
+        0xF05B,
+        0xF05C,
+        0xF05D,
+        0xF05E,
+        0xF05F,
+        0xF060,
+        0xF061,
+        0xF062,
+        0xF063,
+        0xF064,
+        0xF065,
+        0xF066,
+        0xF067,
+        0xF068,
+        0xF069,
+        0xF06A,
+        0xF06B,
+        0xF06C,
+        0xF06D,
+        0xF06E,
+        0xF06F,
+        0xF070,
+        0xF071,
+        0xF072,
+        0xF073,
+        0xF074,
+        0xF075,
+        0xF076,
+        0xF077,
+        0xF078,
+        0xF079,
+        0xF07A,
+        0xF07B,
+        0xF07C,
+        0xF07D,
+        0xF07E,
+        0xF07F,
+        0xF080,
+        0xF081,
+        0xF082,
+        0xF083,
+        0xF084,
+        0xF085,
+        0xF086,
+        0xF087,
+        0xF088,
+        0xF089,
+        0xF08A,
+        0xF08B,
+        0xF08C,
+        0xF08D,
+        0xF08E,
+        0xF08F,
+        0xF090,
+        0xF091,
+        0xF092,
+        0xF093,
+        0xF094,
+        0xF095,
+        0xF096,
+        0xF097,
+        0xF098,
+        0xF099,
+        0xF09A,
+        0xF09B,
+        0xF09C,
+        0xF09D,
+        0xF09E,
+        0xF09F,
+        0xF0A0,
+        0xF0A1,
+        0xF0A2,
+        0xF0A3,
+        0xF0A4,
+        0xF0A5,
+        0xF0A6,
+        0xF0A7,
+        0xF0A8,
+        0xF0A9,
+        0xF0AA,
+        0xF0AB,
+        0xF0AC,
+        0xF0AD,
+        0xF0AE,
+        0xF0AF,
+        0xF0B0,
+        0xF0B1,
+        0xF0B2,
+        0xF0B3,
+        0xF0B4,
+        0xF0B5,
+        0xF0B6,
+        0xF0B7,
+        0xF0B8,
+        0xF0B9,
+        0xF0BA,
+        0xF0BB,
+        0xF0BC,
+        0xF0BD,
+        0xF0BE,
+        0xF0BF,
+        0xF0C0,
+        0xF0C1,
+        0xF0C2,
+        0xF0C3,
+        0xF0C4,
+        0xF0C5,
+        0xF0C6,
+        0xF0C7,
+        0xF0C8,
+        0xF0C9,
+        0xF0CA,
+        0xF0CB,
+        0xF0CC,
+        0xF0CD,
+        0xF0CE,
+        0xF0CF,
+        0xF0D0,
+        0xF0D1,
+        0xF0D2,
+        0xF0D3,
+        0xF0D4,
+        0xF0D5,
+        0xF0D6,
+        0xF0D7,
+        0xF0D8,
+        0xF0D9,
+        0xF0DA,
+        0xF0DB,
+        0xF0DC,
+        0xF0DD,
+        0xF0DE,
+        0xF0DF,
+        0xF0E0,
+        0xF0E1,
+        0xF0E2,
+        0xF0E3,
+        0xF0E4,
+        0xF0E5,
+        0xF0E6,
+        0xF0E7,
+        0xF0E8,
+        0xF0E9,
+        0xF0EA,
+        0xF0EB,
+        0xF0EC,
+        0xF0ED,
+        0xF0EE,
+        0xF0EF,
+        0xF0F0,
+        0xF0F1,
+        0xF0F2,
+        0xF0F3,
+        0xF0F4,
+        0xF0F5,
+        0xF0F6,
+        0xF0F7,
+        0xF0F8,
+        0xF0F9,
+        0xF0FA,
+        0xF0FB,
+        0xF0FC,
+        0xF0FD,
+        0xF0FE,
+        0xF0FF,
+    ],
 };
 
 
@@ -543,6 +802,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: webdings.pm,v $
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.7  2005/03/14 22:01:30  fredo
+    upd 2005
+
+    Revision 1.6  2004/11/26 01:24:54  fredo
+    fixed unicode mapping
+
     Revision 1.5  2004/06/15 09:14:54  fredo
     removed cr+lf
 
